@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -40,6 +40,7 @@
 #include "Kaidan.h"
 #include "MessageModel.h"
 #include "RosterModel.h"
+#include "Settings.h"
 #include "VCardCache.h"
 
 AccountManager *AccountManager::s_instance = nullptr;
@@ -49,14 +50,15 @@ AccountManager *AccountManager::instance()
 	return s_instance;
 }
 
-AccountManager::AccountManager(QSettings *settings, VCardCache *cache, QObject *parent)
+AccountManager::AccountManager(Settings *settings, VCardCache *cache, QObject *parent)
 	: QObject(parent),
-	  m_settings(settings)
+	  m_settings(settings),
+	  m_port(PORT_AUTODETECT)
 {
 	Q_ASSERT(!s_instance);
 	s_instance = this;
 
-	connect(cache, &VCardCache::vCardChanged, this, [=](const QString &jid) {
+	connect(cache, &VCardCache::vCardChanged, this, [this](const QString &jid) {
 		if (m_jid == jid) {
 			emit displayNameChanged();
 		}
@@ -124,7 +126,7 @@ void AccountManager::setHost(const QString &host)
 
 	if (m_host != host) {
 		m_host = host;
-		m_hasNewCredentials = true;
+		m_hasNewConnectionSettings = true;
 
 		locker.unlock();
 		emit hostChanged();
@@ -143,16 +145,16 @@ void AccountManager::setPort(const quint16 port)
 
 	if (m_port != port) {
 		m_port = port;
-		m_hasNewCredentials = true;
+		m_hasNewConnectionSettings = true;
 
 		locker.unlock();
 		emit portChanged();
 	}
 }
 
-quint16 AccountManager::nonCustomPort() const
+quint16 AccountManager::portAutodetect() const
 {
-	return NON_CUSTOM_PORT;
+	return PORT_AUTODETECT;
 }
 
 QString AccountManager::displayName()
@@ -170,7 +172,7 @@ QString AccountManager::displayName()
 void AccountManager::resetCustomConnectionSettings()
 {
 	setHost({});
-	setPort(NON_CUSTOM_PORT);
+	setPort(PORT_AUTODETECT);
 }
 
 bool AccountManager::hasNewCredentials() const
@@ -188,25 +190,35 @@ bool AccountManager::hasEnoughCredentialsForLogin()
 	return !(jid().isEmpty() || password().isEmpty());
 }
 
-bool AccountManager::loadCredentials()
+bool AccountManager::hasNewConnectionSettings() const
+{
+	return m_hasNewConnectionSettings;
+}
+
+void AccountManager::setHasNewConnectionSettings(bool hasNewConnectionSettings)
+{
+	m_hasNewConnectionSettings = hasNewConnectionSettings;
+}
+
+bool AccountManager::loadConnectionData()
 {
 	if (!hasEnoughCredentialsForLogin()) {
 		// Load the credentials from the settings file.
-		setJid(m_settings->value(KAIDAN_SETTINGS_AUTH_JID).toString());
-		setPassword(QByteArray::fromBase64(m_settings->value(KAIDAN_SETTINGS_AUTH_PASSWD).toString().toUtf8()));
+		setJid(m_settings->authJid());
+		setPassword(m_settings->authPassword());
 
 		// Use a default prefix for the JID's resource part if no prefix is already set.
-		setJidResourcePrefix(m_settings->value(KAIDAN_SETTINGS_AUTH_JID_RESOURCE_PREFIX,
-				KAIDAN_JID_RESOURCE_DEFAULT_PREFIX).toString());
+		setJidResourcePrefix(m_settings->authJidResourcePrefix());
 
 		// Load the custom connection setings.
-		setHost(m_settings->value(KAIDAN_SETTINGS_AUTH_HOST).toString());
-		setPort(m_settings->value(KAIDAN_SETTINGS_AUTH_PORT, NON_CUSTOM_PORT).toInt());
+		setHost(m_settings->authHost());
+		setPort(m_settings->authPort());
 
-		// This method is only used to load old credentials. Therefore,
-		// "m_hasNewCredentials" which was set to "true" by setting the credentials in this
-		// method is reset here.
+		// This method is only used to load old credentials and connection settings.
+		// Thus, "m_hasNewCredentials" and "m_hasNewConnectionSettings" which were set to "true" by
+		// setting the credentials and connection settings in this method are reset here.
 		m_hasNewCredentials = false;
+		m_hasNewConnectionSettings = false;
 
 		// If no credentials could be loaded from the settings file, notify the GUI to ask
 		// the user for credentials.
@@ -219,28 +231,28 @@ bool AccountManager::loadCredentials()
 
 void AccountManager::storeJid()
 {
-	m_settings->setValue(KAIDAN_SETTINGS_AUTH_JID, jid());
+	m_settings->setAuthJid(jid());
 }
 
 void AccountManager::storePassword()
 {
-	m_settings->setValue(KAIDAN_SETTINGS_AUTH_PASSWD, QString::fromUtf8(password().toUtf8().toBase64()));
+	m_settings->setAuthPassword(password());
 }
 
 void AccountManager::storeCustomConnectionSettings()
 {
 	if (m_host.isEmpty())
-		m_settings->remove(KAIDAN_SETTINGS_AUTH_HOST);
+		m_settings->resetAuthHost();
 	else
-		m_settings->setValue(KAIDAN_SETTINGS_AUTH_HOST, m_host);
+		m_settings->setAuthHost(m_host);
 
-	if (m_port == NON_CUSTOM_PORT)
-		m_settings->remove(KAIDAN_SETTINGS_AUTH_PORT);
+	if (m_settings->isDefaultAuthPort())
+		m_settings->resetAuthPort();
 	else
-		m_settings->setValue(KAIDAN_SETTINGS_AUTH_PORT, m_port);
+		m_settings->setAuthPort(m_port);
 }
 
-void AccountManager::storeCredentials()
+void AccountManager::storeConnectionData()
 {
 	storeJid();
 	storePassword();
@@ -249,7 +261,7 @@ void AccountManager::storeCredentials()
 
 void AccountManager::deleteCredentials()
 {
-	deleteSettingsInSettingsFile({
+	m_settings->remove({
 		KAIDAN_SETTINGS_AUTH_JID,
 		KAIDAN_SETTINGS_AUTH_JID_RESOURCE_PREFIX,
 		KAIDAN_SETTINGS_AUTH_PASSWD,
@@ -269,10 +281,11 @@ void AccountManager::deleteCredentials()
 
 void AccountManager::deleteSettings()
 {
-	deleteSettingsInSettingsFile({
+	m_settings->remove({
 		KAIDAN_SETTINGS_AUTH_ONLINE,
 		KAIDAN_SETTINGS_NOTIFICATIONS_MUTED,
-		KAIDAN_SETTINGS_FAVORITE_EMOJIS
+		KAIDAN_SETTINGS_FAVORITE_EMOJIS,
+		KAIDAN_SETTINGS_HELP_VISIBILITY_QR_CODE_PAGE,
 	});
 }
 
@@ -285,12 +298,6 @@ void AccountManager::removeAccount(const QString &accountJid)
 	emit RosterModel::instance()->removeItemsRequested(accountJid);
 }
 
-void AccountManager::deleteSettingsInSettingsFile(const QStringList &keys) const
-{
-	for (const QString &key : keys)
-		m_settings->remove(key);
-}
-
 QString AccountManager::generateJidResourceWithRandomSuffix(unsigned int numberOfRandomSuffixCharacters) const
 {
 	return m_jidResourcePrefix % "." % QXmppUtils::generateStanzaHash(numberOfRandomSuffixCharacters);
