@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -34,11 +34,9 @@
 #include <QMutex>
 #include <QObject>
 
-class QSettings;
+class Settings;
 class VCardCache;
 
-constexpr quint16 NON_CUSTOM_PORT = 0;
-
 /**
  * This class manages account-related settings.
  */
@@ -50,13 +48,13 @@ class AccountManager : public QObject
 	Q_PROPERTY(QString password READ password WRITE setPassword NOTIFY passwordChanged)
 	Q_PROPERTY(QString host READ host WRITE setHost NOTIFY hostChanged)
 	Q_PROPERTY(quint16 port READ port WRITE setPort NOTIFY portChanged)
-	Q_PROPERTY(quint16 nonCustomPort READ nonCustomPort CONSTANT)
+	Q_PROPERTY(quint16 portAutodetect READ portAutodetect CONSTANT)
 	Q_PROPERTY(QString displayName READ displayName NOTIFY displayNameChanged)
 
 public:
 	static AccountManager *instance();
 
-	AccountManager(QSettings *settings, VCardCache *cache, QObject *parent = nullptr);
+	AccountManager(Settings *settings, VCardCache *cache, QObject *parent = nullptr);
 
 	/**
 	 * Returns the bare JID of the account.
@@ -132,7 +130,7 @@ public:
 	 *
 	 * This method is thread-safe.
 	 *
-	 * @return the custom port or nonCustomPort if no custom port is set
+	 * @return the custom port or portAutodetect if no custom port is set
 	 */
 	quint16 port();
 
@@ -148,7 +146,7 @@ public:
 	/**
 	 * Returns the port which indicates that no custom port is set.
 	 */
-	quint16 nonCustomPort() const;
+	quint16 portAutodetect() const;
 
 	/**
 	 * Returns the user's display name.
@@ -184,13 +182,28 @@ public:
 	bool hasEnoughCredentialsForLogin();
 
 	/**
-	 * Loads all credentials used to connect to the server.
+	 * Provides a way to cache whether the current connection settings are new to this client.
 	 *
-	 * If credentials are missing for a login, the signal credentialsNeeded() is emitted.
+	 * The connections settings are new to the client if they were not already in use during the
+	 * previous login.
+	 *
+	 * @return whether the connection settings are new
+	 */
+	bool hasNewConnectionSettings() const;
+
+	/**
+	 * Sets whether the current connection settings are new to this client.
+	 *
+	 * @param hasNewConnectionSettings whether the settings are new
+	 */
+	void setHasNewConnectionSettings(bool hasNewConnectionSettings);
+
+	/**
+	 * Loads all credentials and connection settings used to connect to the server.
 	 *
 	 * @return true if the credentials could be loaded, otherwise false
 	 */
-	Q_INVOKABLE bool loadCredentials();
+	Q_INVOKABLE bool loadConnectionData();
 
 	/**
 	 * Stores the currently set JID in the settings file.
@@ -210,9 +223,9 @@ public:
 	void storeCustomConnectionSettings();
 
 	/**
-	 * Stores credentials (jid, password, etc.) in the settings file.
+	 * Stores credentials and connection settings in the settings file.
 	 */
-	void storeCredentials();
+	void storeConnectionData();
 
 	/**
 	 * Deletes all credentials.
@@ -226,7 +239,7 @@ public:
 	 *
 	 * Settings stored in the settings file are also removed from it.
 	 */
- 	void deleteSettings();
+	void deleteSettings();
 
 	/**
 	 * Removes an account.
@@ -274,13 +287,6 @@ signals:
 	void removeAccountRequested(const QString &accountJid);
 
 private:
-	/**
-	 * Deletes settings in the settings / configuration file.
-	 *
-	 * @param keys keys of the settings being deleted
-	 */
-	void deleteSettingsInSettingsFile(const QStringList &keys) const;
-
 	/**
 	 * Generates the JID's resource part with the set JID resource prefix and a suffix
 	 * consisting of a dot followed by random alphanumeric characters.
@@ -291,16 +297,17 @@ private:
 	QString generateJidResourceWithRandomSuffix(unsigned int numberOfRandomSuffixCharacters = 4) const;
 
 	QMutex m_mutex;
-	QSettings *m_settings;
+	Settings *m_settings;
 
 	QString m_jid;
 	QString m_jidResourcePrefix;
 	QString m_jidResource;
 	QString m_password;
 	QString m_host;
-	quint16 m_port = NON_CUSTOM_PORT;
+	quint16 m_port;
 
 	bool m_hasNewCredentials;
+	bool m_hasNewConnectionSettings;
 
 	static AccountManager *s_instance;
 };
