@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -63,7 +63,7 @@ QImage BitsOfBinaryImageProvider::requestImage(const QString &id, QSize *size, c
 {
 	QMutexLocker locker(&m_cacheMutex);
 
-	const auto item = std::find_if(m_cache.begin(), m_cache.end(), [=] (const QXmppBitsOfBinaryData &item) {
+	const auto item = std::find_if(m_cache.begin(), m_cache.end(), [&](const QXmppBitsOfBinaryData &item) {
 		return item.cid().toCidUrl() == id;
 	});
 
@@ -88,7 +88,7 @@ bool BitsOfBinaryImageProvider::addImage(const QXmppBitsOfBinaryData &data)
 		return false;
 	}
 
-	m_cache << data;
+	m_cache.push_back(data);
 	return true;
 }
 
@@ -96,7 +96,12 @@ bool BitsOfBinaryImageProvider::removeImage(const QXmppBitsOfBinaryContentId &ci
 {
 	QMutexLocker locker(&m_cacheMutex);
 
-	return m_cache.end() != std::remove_if(m_cache.begin(), m_cache.end(), [&] (const QXmppBitsOfBinaryData &item) {
+	auto endItr = std::remove_if(m_cache.begin(), m_cache.end(), [&](const QXmppBitsOfBinaryData &item) {
 		return item.cid() == cid;
 	});
+	// check whether anything was removed
+	bool success = endItr != m_cache.end();
+	// resize container
+	m_cache.erase(endItr, m_cache.end());
+	return success;
 }
