@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -32,66 +32,86 @@
 // Qt
 #include <QGuiApplication>
 #include <QSettings>
+#include <QNetworkAccessManager>
 // QXmpp
+#include <QXmppCarbonManagerV2.h>
+#include <QXmppMamManager.h>
+#include <QXmppPubSubManager.h>
 #include <QXmppUtils.h>
+#include <QXmppFileSharingManager.h>
+#include <QXmppHttpFileSharingProvider.h>
+#include <QXmppEncryptedFileSharingProvider.h>
+#include <QXmppHttpUploadManager.h>
+#include <QXmppUploadRequestManager.h>
+#include <QXmppPubSubBaseItem.h>
 // Kaidan
 #include "AccountManager.h"
+#include "AtmManager.h"
 #include "AvatarFileStorage.h"
 #include "DiscoveryManager.h"
-#include "DownloadManager.h"
 #include "Enums.h"
-#include "Globals.h"
+#include "FutureUtils.h"
 #include "Kaidan.h"
 #include "LogHandler.h"
-#include "MessageDb.h"
 #include "MessageHandler.h"
 #include "MessageModel.h"
+#include "OmemoCache.h"
+#include "OmemoManager.h"
 #include "PresenceCache.h"
 #include "RegistrationManager.h"
-#include "RosterDb.h"
 #include "RosterManager.h"
 #include "RosterModel.h"
 #include "ServerFeaturesCache.h"
-#include "TransferCache.h"
-#include "UploadManager.h"
 #include "VCardCache.h"
 #include "VCardManager.h"
 #include "VersionManager.h"
+#include "Settings.h"
+#include "MediaUtils.h"
 
 ClientWorker::Caches::Caches(QObject *parent)
-	: settings(new QSettings(APPLICATION_NAME, APPLICATION_NAME)),
+	: settings(new Settings(parent)),
 	  vCardCache(new VCardCache(parent)),
 	  accountManager(new AccountManager(settings, vCardCache, parent)),
 	  msgModel(new MessageModel(parent)),
 	  rosterModel(new RosterModel(parent)),
+	  omemoCache(new OmemoCache(parent)),
 	  avatarStorage(new AvatarFileStorage(parent)),
 	  serverFeaturesCache(new ServerFeaturesCache(parent)),
-	  presCache(new PresenceCache(parent)),
-	  transferCache(new TransferCache(parent))
+	  presenceCache(new PresenceCache(parent))
 {
-	rosterModel->setMessageModel(msgModel);
 }
 
-ClientWorker::Caches::~Caches()
-{
-	delete settings;
-}
-
-ClientWorker::ClientWorker(Caches *caches, bool enableLogging, QObject* parent)
+ClientWorker::ClientWorker(Caches *caches, Database *database, bool enableLogging, QObject* parent)
 	: QObject(parent),
 	  m_caches(caches),
 	  m_client(new QXmppClient(this)),
 	  m_logger(new LogHandler(m_client, enableLogging, this)),
 	  m_enableLogging(enableLogging),
-	  m_registrationManager(new RegistrationManager(this, m_client, m_caches->settings, this)),
-	  m_vCardManager(new VCardManager(this, m_client, m_caches->avatarStorage, this)),
-	  m_rosterManager(new RosterManager(m_client, m_caches->avatarStorage, m_vCardManager, this)),
-	  m_messageHandler(new MessageHandler(this, m_client, this)),
-	  m_discoveryManager(new DiscoveryManager(m_client, this)),
-	  m_uploadManager(new UploadManager(m_client, m_rosterManager, this)),
-	  m_downloadManager(new DownloadManager(caches->transferCache, this)),
-	  m_versionManager(new VersionManager(m_client, this))
+	  m_networkManager(new QNetworkAccessManager(this))
 {
+	m_client->addNewExtension<QXmppCarbonManagerV2>();
+	m_client->addExtension(new QXmppMamManager);
+	m_client->addExtension(new QXmppPubSubManager);
+	m_client->addNewExtension<QXmppUploadRequestManager>();
+	auto *uploadManager = m_client->addNewExtension<QXmppHttpUploadManager>(m_networkManager);
+
+	m_registrationManager = new RegistrationManager(this, m_client, this);
+	m_vCardManager = new VCardManager(this, m_client, m_caches->avatarStorage, this);
+	m_rosterManager = new RosterManager(this, m_client, this);
+	m_messageHandler = new MessageHandler(this, m_client, this);
+	m_atmManager = new AtmManager(m_client, database, this);
+	m_omemoManager = new OmemoManager(m_client, database, this);
+	m_discoveryManager = new DiscoveryManager(m_client, this);
+	m_versionManager = new VersionManager(m_client, this);
+
+	// file sharing manager
+	m_fileSharingManager = m_client->addNewExtension<QXmppFileSharingManager>();
+	m_fileSharingManager->setMetadataGenerator(MediaUtils::generateMetadata);
+	m_httpProvider = std::make_shared<QXmppHttpFileSharingProvider>(uploadManager, m_networkManager);
+	m_encryptedProvider = std::make_shared<QXmppEncryptedFileSharingProvider>(m_fileSharingManager, m_httpProvider);
+	m_fileSharingManager->registerProvider(m_httpProvider);
+	m_fileSharingManager->registerProvider(m_encryptedProvider);
+
 	connect(m_client, &QXmppClient::connected, this, &ClientWorker::onConnected);
 	connect(m_client, &QXmppClient::disconnected, this, &ClientWorker::onDisconnected);
 
@@ -103,11 +123,12 @@ ClientWorker::ClientWorker(Caches *caches, bool enableLogging, QObject* parent)
 	connect(Kaidan::instance(), &Kaidan::logOutRequested, this, &ClientWorker::logOut);
 
 	// presence
-	connect(m_client, &QXmppClient::presenceReceived, caches->presCache, &PresenceCache::updatePresence);
-	connect(m_client, &QXmppClient::disconnected, caches->presCache, &PresenceCache::clear);
+	auto *presenceCache = PresenceCache::instance();
+	connect(m_client, &QXmppClient::presenceReceived, presenceCache, &PresenceCache::updatePresence);
+	connect(m_client, &QXmppClient::disconnected, presenceCache, &PresenceCache::clear);
 
 	// Reduce the network traffic when the application window is not active.
-	connect(qGuiApp, &QGuiApplication::applicationStateChanged, [=](Qt::ApplicationState state) {
+	connect(qGuiApp, &QGuiApplication::applicationStateChanged, this, [this](Qt::ApplicationState state) {
 		if (state == Qt::ApplicationActive) {
 			m_client->setActive(true);
 		} else {
@@ -120,14 +141,8 @@ ClientWorker::ClientWorker(Caches *caches, bool enableLogging, QObject* parent)
 	connect(Kaidan::instance(), &Kaidan::deleteAccountFromClientAndServer, this, &ClientWorker::deleteAccountFromClientAndServer);
 }
 
-void ClientWorker::initialize()
+void ClientWorker::startTask(const std::function<void ()> &task)
 {
-	// Initialize the random number generator used by "qrand()" for QXmpp < 1.3.0 or QXmpp
-	// built with Qt < 5.10. Please do not use that deprecated method for Kaidan.
-	qsrand(time(nullptr));
-}
-
-void ClientWorker::startTask(const std::function<void ()> task) {
 	if (m_client->isAuthenticated()) {
 		task();
 	} else {
@@ -155,19 +170,25 @@ void ClientWorker::finishTask()
 
 void ClientWorker::logIn()
 {
-	if (!m_isFirstLoginAfterStart || m_caches->settings->value(KAIDAN_SETTINGS_AUTH_ONLINE, true).toBool()) {
-		// Store the latest online state which is restored when opening Kaidan again after closing.
-		m_caches->settings->setValue(KAIDAN_SETTINGS_AUTH_ONLINE, true);
+	const auto jid = AccountManager::instance()->jid();
+	m_atmManager->setAccountJid(jid);
+	m_omemoManager->setAccountJid(jid);
 
-		QXmppConfiguration config;
-		config.setResource(AccountManager::instance()->jidResource());
-		config.setPassword(AccountManager::instance()->password());
-		config.setAutoAcceptSubscriptions(false);
+	await(m_omemoManager->load(), this, [this]() {
+		if (!m_isFirstLoginAfterStart || m_caches->settings->authOnline()) {
+			// Store the latest online state which is restored when opening Kaidan again after closing.
+			m_caches->settings->setAuthOnline(true);
 
-		connectToServer(config);
-	}
+			QXmppConfiguration config;
+			config.setResource(AccountManager::instance()->jidResource());
+			config.setPassword(AccountManager::instance()->password());
+			config.setAutoAcceptSubscriptions(false);
 
-	m_isFirstLoginAfterStart = false;
+			connectToServer(config);
+		}
+
+		m_isFirstLoginAfterStart = false;
+	});
 }
 
 void ClientWorker::connectToRegister()
@@ -198,7 +219,7 @@ void ClientWorker::connectToServer(QXmppConfiguration config)
 			config.setHost(host);
 
 		auto port = AccountManager::instance()->port();
-		if (port != NON_CUSTOM_PORT) {
+		if (port != PORT_AUTODETECT) {
 			config.setPort(port);
 
 			// Set the JID's domain part as the host if no custom host is set.
@@ -225,7 +246,7 @@ void ClientWorker::logOut(bool isApplicationBeingClosed)
 {
 	// Store the latest online state which is restored when opening Kaidan again after closing.
 	if (!isApplicationBeingClosed)
-		m_caches->settings->setValue(KAIDAN_SETTINGS_AUTH_ONLINE, false);
+		m_caches->settings->setAuthOnline(false);
 
 	switch (m_client->state()) {
 	case QXmppClient::DisconnectedState:
@@ -235,10 +256,17 @@ void ClientWorker::logOut(bool isApplicationBeingClosed)
 		m_isDisconnecting = true;
 		break;
 	case QXmppClient::ConnectedState:
-		if (AccountManager::instance()->hasNewCredentials())
+		if (AccountManager::instance()->hasNewCredentials()) {
 			AccountManager::instance()->setHasNewCredentials(false);
+		}
 
-		m_client->disconnectFromServer();
+		if (AccountManager::instance()->hasNewConnectionSettings()) {
+			AccountManager::instance()->setHasNewConnectionSettings(false);
+		}
+
+		await(m_omemoManager->unsubscribeFromDeviceLists(), this, [this] {
+			m_client->disconnectFromServer();
+		});
 	}
 }
 
@@ -264,8 +292,10 @@ void ClientWorker::deleteAccountFromClient()
 		AccountManager::instance()->removeAccount(m_client->configuration().jidBare());
 		m_isAccountToBeDeletedFromClient = false;
 	} else {
-		m_isAccountToBeDeletedFromClient = true;
-		logOut();
+		m_omemoManager->resetOwnDevice().then(this, [this](auto &&) {
+			m_isAccountToBeDeletedFromClient = true;
+			logOut();
+		});
 	}
 }
 
@@ -312,12 +342,14 @@ void ClientWorker::onConnected()
 		return;
 	}
 
-	// The following tasks are only done after a login with new credentials.
-	if (AccountManager::instance()->hasNewCredentials()) {
-		emit loggedInWithNewCredentials();
+	// The following tasks are only done after a login with new credentials or connection settings.
+	if (AccountManager::instance()->hasNewCredentials() || AccountManager::instance()->hasNewConnectionSettings()) {
+		if (AccountManager::instance()->hasNewCredentials()) {
+			emit loggedInWithNewCredentials();
+		}
 
 		// Store the valid settings.
-		AccountManager::instance()->storeCredentials();
+		AccountManager::instance()->storeConnectionData();
 	}
 
 	// Enable auto reconnection so that the client is always trying to reconnect
@@ -325,6 +357,13 @@ void ClientWorker::onConnected()
 	m_client->configuration().setAutoReconnectionEnabled(true);
 
 	MessageModel::instance()->sendPendingMessages();
+
+	// Send read markers that could not be sent yet because the client was offline.
+	runOnThread(RosterModel::instance(), [jid = AccountManager::instance()->jid()]() {
+		RosterModel::instance()->sendPendingReadMarkers(jid);
+	});
+
+	m_omemoManager->setUp();
 }
 
 void ClientWorker::onDisconnected()
@@ -356,17 +395,14 @@ void ClientWorker::onConnectionError(QXmppClient::Error error)
 	// no mutex needed, because this is called from updateClient()
 	qDebug() << "[client] Disconnected:" << error;
 
-	QXmppStanza::Error::Condition xmppStreamError;
-	QAbstractSocket::SocketError socketError;
-
 	switch (error) {
 	case QXmppClient::NoError:
 		Q_UNREACHABLE();
 	case QXmppClient::KeepAliveError:
 		emit connectionErrorChanged(ClientWorker::KeepAliveError);
 		break;
-	case QXmppClient::XmppStreamError:
-		xmppStreamError = m_client->xmppStreamError();
+	case QXmppClient::XmppStreamError: {
+		QXmppStanza::Error::Condition xmppStreamError = m_client->xmppStreamError();
 		qDebug() << "[client] XMPP stream error:" << xmppStreamError;
 		if (xmppStreamError == QXmppStanza::Error::NotAuthorized) {
 			emit connectionErrorChanged(ClientWorker::AuthenticationFailed);
@@ -374,8 +410,9 @@ void ClientWorker::onConnectionError(QXmppClient::Error error)
 			emit connectionErrorChanged(ClientWorker::NotConnected);
 		}
 		break;
-	case QXmppClient::SocketError:
-		socketError = m_client->socketError();
+	}
+	case QXmppClient::SocketError: {
+		QAbstractSocket::SocketError socketError = m_client->socketError();
 		switch (socketError) {
 		case QAbstractSocket::ConnectionRefusedError:
 		case QAbstractSocket::RemoteHostClosedError:
@@ -399,6 +436,7 @@ void ClientWorker::onConnectionError(QXmppClient::Error error)
 		}
 		break;
 	}
+	}
 }
 
 bool ClientWorker::startPendingTasks()
