@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -30,6 +30,7 @@
 
 #pragma once
 
+#include <functional>
 // Qt
 // QXmpp
 #include <QXmppClient.h>
@@ -37,23 +38,28 @@
 #include "Enums.h"
 
 class AccountManager;
+class AtmManager;
 class AvatarFileStorage;
+class Database;
 class DiscoveryManager;
-class DownloadManager;
 class LogHandler;
 class MessageHandler;
 class MessageModel;
-class PresenceCache;
+class OmemoCache;
+class OmemoManager;
 class RegistrationManager;
 class RosterManager;
 class RosterModel;
 class ServerFeaturesCache;
-class TransferCache;
-class UploadManager;
 class VCardCache;
 class VCardManager;
 class VersionManager;
-class QSettings;
+class Settings;
+class QNetworkAccessManager;
+class QXmppFileSharingManager;
+class QXmppHttpFileSharingProvider;
+class QXmppEncryptedFileSharingProvider;
+class PresenceCache;
 
 /**
  * The ClientWorker is used as a QObject-based worker on the ClientThread.
@@ -61,15 +67,14 @@ class QSettings;
 class ClientWorker : public QObject
 {
 	Q_OBJECT
-
 	Q_PROPERTY(RegistrationManager* registrationManager READ registrationManager CONSTANT)
 	Q_PROPERTY(VCardManager* vCardManager READ vCardManager CONSTANT)
 	Q_PROPERTY(RosterManager* rosterManager READ rosterManager CONSTANT)
 	Q_PROPERTY(MessageHandler* messageHandler READ messageHandler CONSTANT)
 	Q_PROPERTY(DiscoveryManager* discoveryManager READ discoveryManager CONSTANT)
-	Q_PROPERTY(UploadManager* uploadManager READ uploadManager CONSTANT)
-	Q_PROPERTY(DownloadManager* downloadManager READ downloadManager CONSTANT)
 	Q_PROPERTY(VersionManager* versionManager READ versionManager CONSTANT)
+	Q_PROPERTY(AtmManager* atmManager READ atmManager CONSTANT)
+	Q_PROPERTY(OmemoManager* omemoManager READ omemoManager CONSTANT)
 
 public:
 	/**
@@ -92,17 +97,16 @@ public:
 
 	struct Caches {
 		Caches(QObject *parent = nullptr);
-		~Caches();
 
-		QSettings *settings;
+		Settings *settings;
 		VCardCache *vCardCache;
 		AccountManager *accountManager;
 		MessageModel *msgModel;
 		RosterModel *rosterModel;
+		OmemoCache *omemoCache;
 		AvatarFileStorage *avatarStorage;
 		ServerFeaturesCache *serverFeaturesCache;
-		PresenceCache *presCache;
-		TransferCache* transferCache;
+		PresenceCache *presenceCache;
 	};
 
 	/**
@@ -110,12 +114,7 @@ public:
 	 * @param enableLogging If logging of the XMPP stream should be done.
 	 * @param parent Optional QObject-based parent.
 	 */
-	ClientWorker(Caches *caches, bool enableLogging, QObject *parent = nullptr);
-
-	/**
-	 * Initializes this client worker as soon as it runs in a separate thread.
-	 */
-	void initialize();
+	ClientWorker(Caches *caches, Database *database, bool enableLogging, QObject *parent = nullptr);
 
 	RegistrationManager *registrationManager() const
 	{
@@ -142,26 +141,46 @@ public:
 		return m_discoveryManager;
 	}
 
-	UploadManager *uploadManager() const
-	{
-		return m_uploadManager;
-	}
-
-	DownloadManager *downloadManager() const
-	{
-		return m_downloadManager;
-	}
-
 	VersionManager *versionManager() const
 	{
 		return m_versionManager;
 	}
 
+	AtmManager *atmManager() const
+	{
+		return m_atmManager;
+	}
+
+	OmemoManager *omemoManager() const
+	{
+		return m_omemoManager;
+	}
+
 	Caches *caches() const
 	{
 		return m_caches;
 	}
 
+	QXmppFileSharingManager *fileSharingManager() const
+	{
+		return m_fileSharingManager;
+	}
+
+	std::shared_ptr<QXmppHttpFileSharingProvider> httpFileSharingProvider() const
+	{
+		return m_httpProvider;
+	}
+
+	std::shared_ptr<QXmppEncryptedFileSharingProvider> encryptedHttpFileSharingProvider() const
+	{
+		return m_encryptedProvider;
+	}
+
+	QXmppClient *xmppClient() const
+	{
+		return m_client;
+	}
+
 	/**
 	 * Starts or enqueues a task which will be executed after successful login (e.g. a
 	 * nickname change).
@@ -177,7 +196,7 @@ public:
 	 * @param task task which is run directly if the user is logged in or enqueued to be
 	 * run after an automatic login
 	 */
-	void startTask(const std::function<void ()> task);
+	void startTask(const std::function<void ()> &task);
 
 	/**
 	 * Finishes a task started by "startTask()".
@@ -303,16 +322,20 @@ private:
 	QXmppClient *m_client;
 	LogHandler *m_logger;
 	bool m_enableLogging;
+	QNetworkAccessManager *m_networkManager;
 
-	RegistrationManager *const m_registrationManager;
-	VCardManager *const m_vCardManager;
-	RosterManager *const m_rosterManager;
-	MessageHandler *const m_messageHandler;
-	DiscoveryManager *const m_discoveryManager;
-	UploadManager *const m_uploadManager;
-	DownloadManager *const m_downloadManager;
-	VersionManager *const m_versionManager;
+	RegistrationManager *m_registrationManager;
+	VCardManager *m_vCardManager;
+	RosterManager *m_rosterManager;
+	AtmManager *m_atmManager;
+	OmemoManager *m_omemoManager;
+	MessageHandler *m_messageHandler;
+	DiscoveryManager *m_discoveryManager;
+	VersionManager *m_versionManager;
 
+	QXmppFileSharingManager *m_fileSharingManager;
+	std::shared_ptr<QXmppHttpFileSharingProvider> m_httpProvider;
+	std::shared_ptr<QXmppEncryptedFileSharingProvider> m_encryptedProvider;
 	QList<std::function<void ()>> m_pendingTasks;
 	uint m_activeTasks = 0;
 
