@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -44,12 +44,12 @@ bool CredentialsValidator::isAccountJidValid(const QString &jid)
 
 bool CredentialsValidator::isUsernameValid(const QString &username)
 {
-	return !(username.isEmpty() || username.contains(" "));
+	return !(username.isEmpty() || username.contains(u' '));
 }
 
 bool CredentialsValidator::isServerValid(const QString &server)
 {
-	return !(server.isEmpty() || server.contains(" "));
+	return !(server.isEmpty() || server.contains(u' '));
 }
 
 bool CredentialsValidator::isPasswordValid(const QString &password)
