@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -30,10 +30,13 @@
 
 #pragma once
 
+#include <memory>
 #include <QObject>
-#include <QSqlDatabase>
 
 class QSqlQuery;
+class QSqlDatabase;
+class QThreadPool;
+struct DatabasePrivate;
 
 /**
  * The Database class manages the SQL database. It opens the database and converts old
@@ -42,35 +45,35 @@ class QSqlQuery;
 class Database : public QObject
 {
 	Q_OBJECT
+	friend class DatabaseComponent;
 
 public:
 	Database(QObject *parent = nullptr);
 	~Database();
 
 	/**
-	 * Opens the database for reading and writing and guarantees the database to be
-	 * up-to-date.
+	 * Converts the database to the latest version and guarantees that all tables have
+	 * been created.
 	 */
-	void openDatabase();
+	void createTables();
 
-	/**
-	 * Begins a transaction if none has been started.
-	 */
-	void transaction();
-
-	/**
-	 * Commits the transaction if every transaction has been finished.
-	 */
-	void commit();
-
-signals:
-	/// Emit, to begin a transaction if none has been started already.
-	void transactionRequested();
-
-	/// Emit, to commit the transaction if every transaction has been finished.
-	void commitRequested();
+	/// Transaction on random thread from the thread pool (should be replaced in the
+	/// future).
+	void startTransaction();
+	void commitTransaction();
 
 private:
+	QObject *dbWorker() const;
+	QSqlDatabase currentDatabase();
+	QSqlQuery createQuery();
+
+	/// Returns the number of active transactions on the current thread.
+	int &activeTransactions();
+	/// Begins a transaction if none has been started.
+	void transaction();
+	/// Commits the transaction if every transaction has been finished.
+	void commit();
+
 	/**
 	 * @return true if the database has to be converted using @c convertDatabase()
 	 * because the database is not up-to-date.
@@ -92,13 +95,6 @@ private:
 	 */
 	void saveDatabaseInfo();
 
-	/*
-	 * These methods create new tables, they are used when creating a new database.
-	 */
-	void createDbInfoTable();
-	void createRosterTable();
-	void createMessagesTable();
-
 	/**
 	 * Creates a new database without content.
 	 */
@@ -119,16 +115,20 @@ private:
 	void convertDatabaseToV11();
 	void convertDatabaseToV12();
 	void convertDatabaseToV13();
+	void convertDatabaseToV14();
+	void convertDatabaseToV15();
+	void convertDatabaseToV16();
+	void convertDatabaseToV17();
+	void convertDatabaseToV18();
+	void convertDatabaseToV19();
+	void convertDatabaseToV20();
+	void convertDatabaseToV21();
+	void convertDatabaseToV22();
+	void convertDatabaseToV23();
+	void convertDatabaseToV24();
+	void convertDatabaseToV25();
+	void convertDatabaseToV26();
+	void convertDatabaseToV27();
 
-	QSqlDatabase m_database;
-
-	/**
-	 * -1	: Database not loaded.
-	 * 0	: Database not existent.
-	 * 1	: Old database before Kaidan v0.3.
-	 * > 1	: Database version.
-	 */
-	int m_version = -1;
-
-	int m_transactions = 0;
+	std::unique_ptr<DatabasePrivate> d;
 };
