@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -57,11 +57,6 @@ public:
 	 */
 	void handleItems(const QXmppDiscoveryIq&);
 
-	/**
-	 * Handles incoming results of disco info requests
-	 */
-	void handleInfo(const QXmppDiscoveryIq&);
-
 private:
 	QXmppClient *m_client;
 	QXmppDiscoveryManager *m_manager;
