@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -84,7 +84,8 @@ namespace Enums {
 		Pending,
 		Sent,
 		Delivered,
-		Error
+		Error,
+		Draft
 	};
 	Q_ENUM_NS(DeliveryState)
 
