@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -41,28 +41,45 @@
 #define KAIDAN_SETTINGS_AUTH_HOST "auth/host"
 #define KAIDAN_SETTINGS_AUTH_PORT "auth/port"
 #define KAIDAN_SETTINGS_AUTH_PASSWD_VISIBILITY "auth/passwordVisibility"
+#define KAIDAN_SETTINGS_ENCRYPTION "encryption"
 #define KAIDAN_SETTINGS_NOTIFICATIONS_MUTED "muted/"
 #define KAIDAN_SETTINGS_FAVORITE_EMOJIS "emojis/favorites"
+#define KAIDAN_SETTINGS_WINDOW_POSITION "window/position"
 #define KAIDAN_SETTINGS_WINDOW_SIZE "window/size"
+#define KAIDAN_SETTINGS_HELP_VISIBILITY_QR_CODE_PAGE "helpVisibility/qrCodePage"
 
 #define KAIDAN_JID_RESOURCE_DEFAULT_PREFIX APPLICATION_DISPLAY_NAME
 
 #define INVITATION_URL "https://i.kaidan.im/#"
+#define APPLICATION_WEBSITE_URL "https://www.kaidan.im"
 #define APPLICATION_SOURCE_CODE_URL "https://invent.kde.org/network/kaidan"
 #define ISSUE_TRACKING_URL "https://invent.kde.org/network/kaidan/issues"
+#define DONATION_URL "https://liberapay.com/kaidan"
+#define MASTODON_URL "https://fosstodon.org/@kaidan"
 
 constexpr auto MESSAGE_MAX_CHARS = 1e4;
 
-// XML namespaces
-#define NS_CARBONS "urn:xmpp:carbons:2"
-
 // SQL
-#define DB_CONNECTION "kaidan-messages"
-#define DB_FILENAME "messages.sqlite3"
-#define DB_MSG_QUERY_LIMIT 20
+#define DB_FILE_BASE_NAME "kaidan"
 #define DB_TABLE_INFO "dbinfo"
-#define DB_TABLE_ROSTER "Roster"
-#define DB_TABLE_MESSAGES "Messages"
+#define DB_TABLE_ROSTER "roster"
+#define DB_TABLE_MESSAGES "messages"
+#define DB_VIEW_CHAT_MESSAGES "chatMessages"
+#define DB_VIEW_DRAFT_MESSAGES "draftMessages"
+#define DB_TABLE_FILES "files"
+#define DB_TABLE_FILE_HASHES "fileHashes"
+#define DB_TABLE_FILE_HTTP_SOURCES "fileHttpSources"
+#define DB_TABLE_FILE_ENCRYPTED_SOURCES "fileEncryptedSources"
+#define DB_TABLE_MESSAGE_REACTIONS "messageReactions"
+#define DB_TABLE_TRUST_SECURITY_POLICIES "trustSecurityPolicies"
+#define DB_TABLE_TRUST_OWN_KEYS "trustOwnKeys"
+#define DB_TABLE_TRUST_KEYS "trustKeys"
+#define DB_TABLE_TRUST_KEYS_UNPROCESSED "trustKeysUnprocessed"
+#define DB_TABLE_OMEMO_DEVICES "omemoDevices"
+#define DB_TABLE_OMEMO_OWN_DEVICES "omemoDevicesOwn"
+#define DB_TABLE_OMEMO_PRE_KEY_PAIRS "omemoPreKeyPairs"
+#define DB_TABLE_OMEMO_SIGNED_PRE_KEY_PAIRS "omemoPreKeyPairsSigned"
+#define DB_QUERY_LIMIT_MESSAGES 20
 
 //
 // Credential generation
@@ -90,15 +107,15 @@ constexpr auto GENERATED_PASSWORD_LENGTH_UPPER_BOUND = 30;
 #define GENERATED_PASSWORD_ALPHABET_LENGTH GENERATED_PASSWORD_ALPHABET.size()
 
 /**
- * Path of the JSON server list file
+ * Path of the JSON provider list file
  */
-#define SERVER_LIST_FILE_PATH QStringLiteral(":/data/servers.json")
+#define PROVIDER_LIST_FILE_PATH QStringLiteral(":/data/providers.json")
 
 /**
- * Number of servers required in a country so that only servers from that country are
+ * Number of providers required in a country so that only providers from that country are
  * randomly selected.
  */
-constexpr auto SERVER_LIST_MIN_SERVERS_FROM_COUNTRY = 2;
+constexpr auto PROVIDER_LIST_MIN_PROVIDERS_FROM_COUNTRY = 2;
 
 /**
  * Name of the @c QQuickImageProvider for Bits of Binary.
@@ -107,5 +124,9 @@ constexpr auto SERVER_LIST_MIN_SERVERS_FROM_COUNTRY = 2;
 
 // JPEG export quality used when saving images lossy (e.g. when saving images from clipboard)
 constexpr auto JPEG_EXPORT_QUALITY = 85;
+// Maximum file size for reading files just to generate an image thumbnail.
+constexpr auto THUMBNAIL_GENERATION_MAX_FILE_SIZE = 10 * 1024 * 1024;
+// Width and height of generated file thumbnails.
+constexpr auto THUMBNAIL_PIXEL_SIZE = 50;
 
 #endif // GLOBALS_H
