@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -61,14 +61,21 @@ void LogHandler::enableLogging(bool enabled)
 
 void LogHandler::handleLog(QXmppLogger::MessageType type, const QString &text)
 {
-	if (type == QXmppLogger::ReceivedMessage)
+	switch (type) {
+	case QXmppLogger::ReceivedMessage:
 		qDebug() << "[client] [incoming] <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<";
-	else if (type == QXmppLogger::SentMessage)
+		qDebug().noquote() << makeXmlPretty(text);
+		break;
+	case QXmppLogger::SentMessage:
 		qDebug() << "[client] [outgoing] >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>";
-	else
-		return;
-
-	qDebug().noquote() << makeXmlPretty(text);
+		qDebug().noquote() << makeXmlPretty(text);
+		break;
+	case QXmppLogger::WarningMessage:
+		qDebug().noquote() << "[client] [warn]" << text;
+		break;
+	default:
+		break;
+	}
 }
 
 QString LogHandler::makeXmlPretty(QString xmlIn)
