@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -30,18 +30,54 @@
 
 #pragma once
 
+#include <QDateTime>
+#include <QObject>
+#include <QUuid>
+
+class KNotification;
+class QDateTime;
 class QString;
 
-class Notifications
+class Notifications : public QObject
 {
+	Q_OBJECT
+
 public:
+	struct NotificationWrapper
+	{
+		QUuid id;
+		QString accountJid;
+		QString chatJid;
+		QDateTime initalTimestamp;
+		QString latestMessageId;
+		QVector<QString> messages;
+		bool isDeletionEnabled = true;
+		KNotification *notification = nullptr;
+	};
+
+	static Notifications *instance();
+
+	explicit Notifications(QObject *parent = nullptr);
+
 	/**
 	 * Sends a system notification for a chat message.
 	 *
 	 * @param accountJid JID of the message's account
 	 * @param chatJid JID of the message's chat
-	 * @param chatName name of the message's chat
-	 * @param message message to show
+	 * @param messageId ID of the message
+	 * @param messageBody body of the message to display as the notification's text
 	 */
-	static void sendMessageNotification(const QString &accountJid, const QString &chatJid, const QString &chatName, const QString &message);
+	void sendMessageNotification(const QString &accountJid, const QString &chatJid, const QString &messageId, const QString &messageBody);
+
+	void closeMessageNotification(const QString &accountJid, const QString &chatJid);
+
+	/**
+	 * Emitted to close all chat message notifications of the same age or older than a timestamp.
+	 */
+	Q_SIGNAL void closeMessageNotificationRequested(const QString &accountJid, const QString &chatJid);
+
+private:
+	QVector<NotificationWrapper> m_openNotifications;
+
+	static Notifications *s_instance;
 };
