@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -46,7 +46,7 @@ QString Presence::availabilityToIcon(Availability type)
 	case Away:
 		return QStringLiteral("im-user-away");
 	case DND:
-		return QStringLiteral("im-kick-user");
+		return QStringLiteral("im-user-busy");
 	case XA:
 		return QStringLiteral("im-user-away");
 	case Offline:
@@ -78,7 +78,6 @@ QString Presence::availabilityToText(Availability type)
 
 QColor Presence::availabilityToColor(Availability type)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
 	switch (type) {
 	case Online:
 		return QColorConstants::Svg::green;
@@ -93,22 +92,6 @@ QColor Presence::availabilityToColor(Availability type)
 	case Offline:
 		return QColorConstants::Svg::silver;
 	}
-#else
-	switch (type) {
-	case Online:
-		return "green";
-	case Chat:
-		return "darkgreen";
-	case Away:
-		return "orange";
-	case DND:
-		return QColor::fromRgb(218, 68, 83);
-	case XA:
-		return "orange";
-	case Offline:
-		return "silver";
-	}
-#endif
 	Q_UNREACHABLE();
 	return {};
 }
@@ -153,6 +136,17 @@ QList<QString> PresenceCache::resources(const QString &jid)
 	return m_presences.value(jid).keys();
 }
 
+/**
+ * Returns the count of a JID's available resources.
+ *
+ * @param jid JID whose resources are counted
+ * @return the resources count
+ */
+int PresenceCache::resourcesCount(const QString &jid)
+{
+	return m_presences.value(jid).size();
+}
+
 std::optional<QXmppPresence> PresenceCache::presence(const QString &jid, const QString &resource)
 {
 	if (const auto itr = m_presences.constFind(jid); itr != m_presences.cend()) {
@@ -299,6 +293,11 @@ void UserPresenceWatcher::setJid(const QString &jid)
 	}
 }
 
+/**
+ * Returns the resource whose presence changes are watched.
+ *
+ * @return the watched resource
+ */
 QString UserPresenceWatcher::resource() const
 {
 	return m_resource;
@@ -340,9 +339,9 @@ void UserPresenceWatcher::handlePresencesCleared()
 }
 
 /**
- * Sets the resource and calls the updated-signals for all properties, if the resource
- * changed.
+ * Sets the resource whose presence changes are watched.
  *
+ * @param resource resource to be watched
  * @param autoPicked Whether the resource was picked automatically (@c true) or should be
  * fixed to this value (@c false).
  *
@@ -382,3 +381,52 @@ bool UserPresenceWatcher::autoPickResource()
 	}
 	return false;
 }
+
+UserResourcesWatcher::UserResourcesWatcher(QObject *parent)
+	: QObject(parent)
+{
+	connect(PresenceCache::instance(), &PresenceCache::presenceChanged,
+	        this, [this](PresenceCache::ChangeType, const QString &, const QString &) {
+		emit resourcesCountChanged();
+	});
+
+	connect(PresenceCache::instance(), &PresenceCache::presencesCleared,
+	        this, &UserResourcesWatcher::resourcesCountChanged);
+}
+
+/**
+ * Returns the JID whose resource changes are watched.
+ *
+ * @return the watched JID
+ */
+QString UserResourcesWatcher::jid() const
+{
+	return m_jid;
+}
+
+/**
+ * Sets the JID whose resource changes are watched.
+ *
+ * @param jid JID to be watched
+ */
+void UserResourcesWatcher::setJid(const QString &jid)
+{
+	if (m_jid != jid) {
+		m_jid = jid;
+		emit jidChanged();
+
+		// That signal is emitted to reload the resources in QML after setting
+		// the JID.
+		emit resourcesCountChanged();
+	}
+}
+
+/**
+ * Returns the count of available resources.
+ *
+ * @return the resources count
+ */
+int UserResourcesWatcher::resourcesCount()
+{
+	return PresenceCache::instance()->resourcesCount(m_jid);
+}
