@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -94,6 +94,7 @@ public:
 
 	QString pickIdealResource(const QString &jid);
 	QList<QString> resources(const QString &jid);
+	int resourcesCount(const QString &jid);
 	std::optional<QXmppPresence> presence(const QString &jid, const QString &resource);
 
 public slots:
@@ -165,3 +166,24 @@ private:
 	QString m_resource;
 	bool m_resourceAutoPicked;
 };
+
+class UserResourcesWatcher : public QObject
+{
+	Q_OBJECT
+	Q_PROPERTY(QString jid READ jid WRITE setJid NOTIFY jidChanged)
+	Q_PROPERTY(int resourcesCount READ resourcesCount NOTIFY resourcesCountChanged)
+
+public:
+	explicit UserResourcesWatcher(QObject *parent = nullptr);
+
+	QString jid() const;
+	void setJid(const QString &jid);
+
+	int resourcesCount();
+
+	Q_SIGNAL void jidChanged();
+	Q_SIGNAL void resourcesCountChanged();
+
+private:
+	QString m_jid;
+};
