@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -40,6 +40,9 @@
 #include <QStringBuilder>
 // QXmpp
 #include "qxmpp-exts/QXmppColorGenerator.h"
+#include "qxmpp-exts/QXmppUri.h"
+// Kaidan
+#include "MessageModel.h"
 
 static QmlUtils *s_instance;
 
@@ -130,9 +133,69 @@ QString QmlUtils::getResourcePath(const QString &name)
 	return QString();
 }
 
+QUrl QmlUtils::applicationWebsiteUrl()
+{
+	return { QStringLiteral(APPLICATION_WEBSITE_URL) };
+}
+
 QUrl QmlUtils::issueTrackingUrl()
 {
-	return {QStringLiteral(ISSUE_TRACKING_URL)};
+	return { QStringLiteral(ISSUE_TRACKING_URL) };
+}
+
+QUrl QmlUtils::donationUrl()
+{
+	return { QStringLiteral(DONATION_URL) };
+}
+
+QUrl QmlUtils::mastodonUrl()
+{
+	return { QStringLiteral(MASTODON_URL) };
+}
+
+QUrl QmlUtils::trustMessageUri(const QString &jid)
+{
+	return { trustMessageUriString(jid) };
+}
+
+QString QmlUtils::trustMessageUriString(const QString &jid)
+{
+	const auto keys = MessageModel::instance()->keys().value(jid);
+	QList<QString> authenticatedKeys;
+	QList<QString> distrustedKeys;
+
+	for (auto itr = keys.constBegin(); itr != keys.constEnd(); ++itr) {
+		const auto key = itr.key().toHex();
+		const auto trustLevel = itr.value();
+
+		if (trustLevel == QXmpp::TrustLevel::Authenticated) {
+			authenticatedKeys.append(key);
+		} else if (trustLevel == QXmpp::TrustLevel::ManuallyDistrusted) {
+			distrustedKeys.append(key);
+		}
+	}
+
+	QXmppUri uri;
+	uri.setJid(jid);
+
+	// Create a Trust Message URI only if there are keys for it.
+	if (!authenticatedKeys.isEmpty() || !distrustedKeys.isEmpty()) {
+		uri.setAction(QXmppUri::TrustMessage);
+		// TODO: Find solution to pass enum to "uri.setEncryption()" instead of string (see QXmppGlobal::encryptionToString())
+		uri.setEncryption(QStringLiteral("urn:xmpp:omemo:2"));
+		uri.setTrustedKeysIds(authenticatedKeys);
+		uri.setDistrustedKeysIds(distrustedKeys);
+	}
+
+	return uri.toString();
+}
+
+QUrl QmlUtils::groupChatUri(const QString &groupChatJid)
+{
+	QXmppUri uri;
+	uri.setJid(groupChatJid);
+	uri.setAction(QXmppUri::Join);
+	return { uri.toString() };
 }
 
 bool QmlUtils::isImageFile(const QUrl &fileUrl)
@@ -151,10 +214,13 @@ QString QmlUtils::fileNameFromUrl(const QUrl &url)
 	return QUrl(url).fileName();
 }
 
-QString QmlUtils::fileSizeFromUrl(const QUrl &url)
+QString QmlUtils::formattedDataSize(qint64 fileSize)
 {
-	return QLocale::system().formattedDataSize(
-	            QFileInfo(QUrl(url).toLocalFile()).size());
+	if (fileSize < 0) {
+		return tr("Unknown size");
+	}
+
+	return QLocale::system().formattedDataSize(fileSize);
 }
 
 QString QmlUtils::formatMessage(const QString &message)
@@ -257,3 +323,8 @@ QString QmlUtils::processMsgFormatting(const QStringList &list, bool isFirst)
 
 	return (isFirst ? QString() : " ") + list.first() + processMsgFormatting(list.mid(1), false);
 }
+
+QString QmlUtils::osmUserAgent()
+{
+	return u"" APPLICATION_NAME % QChar(u'/') % u"" VERSION_STRING;
+}
