@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -38,6 +38,8 @@
 
 #include "AccountManager.h"
 #include "Kaidan.h"
+#include "QmlUtils.h"
+#include "Settings.h"
 #include "qxmpp-exts/QXmppUri.h"
 
 #include <stdexcept>
@@ -57,24 +59,31 @@ QImage QrCodeGenerator::generateLoginUriQrCode(int edgePixelCount)
 	uri.setJid(AccountManager::instance()->jid());
 	uri.setAction(QXmppUri::Login);
 
-	if (Kaidan::instance()->passwordVisibility() != Kaidan::PasswordInvisible)
+	if (Kaidan::instance()->settings()->authPasswordVisibility() != Kaidan::PasswordInvisible)
 		uri.setPassword(AccountManager::instance()->password());
 
 	return generateQrCode(edgePixelCount, uri.toString());
 }
 
-QImage QrCodeGenerator::generateBareJidQrCode(int edgePixelCount, const QString &bareJid)
+QImage QrCodeGenerator::generateOwnTrustMessageQrCode(int edgePixelCount)
 {
-	QXmppUri uri;
-	uri.setJid(bareJid);
+	return generateTrustMessageQrCode(edgePixelCount, AccountManager::instance()->jid());
+}
 
-	return generateQrCode(edgePixelCount, uri.toString());
+QImage QrCodeGenerator::generateContactTrustMessageQrCode(int edgePixelCount, const QString &contactJid)
+{
+	return generateTrustMessageQrCode(edgePixelCount, contactJid);
+}
+
+QImage QrCodeGenerator::generateTrustMessageQrCode(int edgePixelCount, const QString &jid)
+{
+	return generateQrCode(edgePixelCount, QmlUtils::trustMessageUriString(jid));
 }
 
 QImage QrCodeGenerator::generateQrCode(int edgePixelCount, const QString &text)
 {
 	try {
-		ZXing::MultiFormatWriter writer(ZXing::BarcodeFormat::QR_CODE);
+		ZXing::MultiFormatWriter writer(ZXing::BarcodeFormat::QRCode);
 		const ZXing::BitMatrix &bitMatrix = writer.encode(text.toStdWString(), edgePixelCount, edgePixelCount);
 		return toImage(bitMatrix);
 	} catch (const std::invalid_argument &e) {
