@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -42,11 +42,10 @@
 #include "RegistrationDataFormModel.h"
 #include "ServerFeaturesCache.h"
 
-RegistrationManager::RegistrationManager(ClientWorker *clientWorker, QXmppClient *client, QSettings *settings, QObject *parent)
+RegistrationManager::RegistrationManager(ClientWorker *clientWorker, QXmppClient *client, QObject *parent)
 	: QObject(parent),
 	  m_clientWorker(clientWorker),
 	  m_client(client),
-	  m_settings(settings),
 	  m_manager(new QXmppRegistrationManager),
 	  m_dataFormModel(new RegistrationDataFormModel())
 {
@@ -101,7 +100,7 @@ void RegistrationManager::sendRegistrationForm()
 void RegistrationManager::changePassword(const QString &newPassword)
 {
 	m_clientWorker->startTask(
-		[=] () {
+		[this, newPassword] {
 			m_manager->changePassword(newPassword);
 		}
 	);
@@ -123,19 +122,20 @@ void RegistrationManager::handleRegistrationFormReceived(const QXmppRegisterIq &
 
 	// If there is no registration data form, try to use an out-of-band URL.
 	if (newDataForm.fields().isEmpty()) {
-#if QXMPP_VERSION >= QT_VERSION_CHECK(1, 5, 0)
 		// If there is a standardized out-of-band URL, use that.
 		if (!iq.outOfBandUrl().isEmpty()) {
 			emit Kaidan::instance()->registrationOutOfBandUrlReceived(iq.outOfBandUrl());
+			setRegisterOnConnectEnabled(false);
 			return;
 		}
-#endif
+
 		// Try to find an out-of-band URL within the instructions element.
 		// Most servers include a text with a link to the website.
 		const auto words = iq.instructions().split(u' ');
 		for (const auto &instructionPart : words) {
 			if (instructionPart.startsWith(u"https://")) {
 				emit Kaidan::instance()->registrationOutOfBandUrlReceived(instructionPart);
+				setRegisterOnConnectEnabled(false);
 				return;
 			}
 		}
@@ -143,6 +143,7 @@ void RegistrationManager::handleRegistrationFormReceived(const QXmppRegisterIq &
 		// If no URL has been found in the instructions, there is a
 		// problem with the server.
 		emit m_clientWorker->connectionErrorChanged(ClientWorker::RegistrationUnsupported);
+		setRegisterOnConnectEnabled(false);
 		return;
 	}
 
@@ -208,12 +209,6 @@ void RegistrationManager::handleRegistrationFailed(const QXmppStanza::Error &err
 		}
 		break;
 	default:
-#if QXMPP_VERSION == QT_VERSION_CHECK(1, 2, 0)
-		// Workaround: Catch an error which is wrongly emitted by QXmpp
-		// v1.2.0 although the registration was successful.
-		if (error.text().isEmpty())
-			return;
-#endif
 		break;
 	}
 
@@ -299,6 +294,11 @@ void RegistrationManager::cleanUpLastForm()
 	delete m_dataFormModel;
 
 	// Remove content IDs from the last form.
-	for (const auto &cid : qAsConst(m_contentIdsToRemove))
-		BitsOfBinaryImageProvider::instance()->removeImage(cid);
+	for (auto itr = m_contentIdsToRemove.begin(); itr != m_contentIdsToRemove.end();) {
+		if (BitsOfBinaryImageProvider::instance()->removeImage(*itr)) {
+			itr = m_contentIdsToRemove.erase(itr);
+		} else {
+			++itr;
+		}
+	}
 }
