@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -41,7 +41,6 @@
 class ClientWorker;
 class RegistrationDataFormModel;
 class DataFormModel;
-class QSettings;
 class QXmppRegistrationManager;
 class QXmppClient;
 class QXmppDataForm;
@@ -63,7 +62,7 @@ public:
 	};
 	Q_ENUM(RegistrationError)
 
-	RegistrationManager(ClientWorker *clientWorker, QXmppClient *client, QSettings *settings, QObject *parent = nullptr);
+	RegistrationManager(ClientWorker *clientWorker, QXmppClient *client, QObject *parent = nullptr);
 
 	/**
 	 * Sets whether a registration is requested for the next time when the client connects to the server.
@@ -168,7 +167,6 @@ private:
 
 	ClientWorker *m_clientWorker;
 	QXmppClient *m_client;
-	QSettings *m_settings;
 	QXmppRegistrationManager *m_manager;
 	RegistrationDataFormModel *m_dataFormModel;
 	QVector<QXmppBitsOfBinaryContentId> m_contentIdsToRemove;
