@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -37,6 +37,7 @@ class QXmppClient;
 class QXmppRosterManager;
 // Kaidan
 class AvatarFileStorage;
+class ClientWorker;
 class VCardManager;
 
 class RosterManager : public QObject
@@ -44,7 +45,15 @@ class RosterManager : public QObject
 	Q_OBJECT
 
 public:
-	RosterManager(QXmppClient *client, AvatarFileStorage *avatarStorage, VCardManager *vCardManager, QObject *parent = nullptr);
+	RosterManager(ClientWorker *clientWorker, QXmppClient *client, QObject *parent = nullptr);
+
+	void addContact(const QString &jid, const QString &name = {}, const QString &msg = {});
+	void removeContact(const QString &jid);
+	void renameContact(const QString &jid, const QString &newContactName);
+
+	void subscribeToPresence(const QString &contactJid);
+	void acceptSubscriptionToPresence(const QString &contactJid);
+	void refuseSubscriptionToPresence(const QString &contactJid);
 
 signals:
 	/**
@@ -58,8 +67,9 @@ signals:
 	 *
 	 * @param nick A simple nick name for the new contact, which should be
 	 *             used to display in the roster.
+	 * @param msg message presented to the added contact
 	 */
-	void addContactRequested(const QString &jid, const QString &nick, const QString &msg);
+	void addContactRequested(const QString &jid, const QString &nick = {}, const QString &msg = {});
 
 	/**
 	 * Remove a contact from your roster
@@ -73,15 +83,14 @@ signals:
 	 */
 	void renameContactRequested(const QString &jid, const QString &newContactName);
 
-public slots:
-	void addContact(const QString &jid, const QString &name, const QString &msg);
-	void removeContact(const QString &jid);
-	void renameContact(const QString &jid, const QString &newContactName);
-
-private slots:
-	void populateRoster();
+	void subscribeToPresenceRequested(const QString &contactJid);
+	void acceptSubscriptionToPresenceRequested(const QString &contactJid);
+	void refuseSubscriptionToPresenceRequested(const QString &contactJid);
 
 private:
+	void populateRoster();
+
+	ClientWorker *m_clientWorker;
 	QXmppClient *m_client;
 	AvatarFileStorage *m_avatarStorage;
 	VCardManager *m_vCardManager;
