@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -34,13 +34,14 @@
 #include <optional>
 // Qt
 #include <QAbstractListModel>
+#include <QFuture>
 #include <QVector>
 // Kaidan
 #include "RosterItem.h"
 
 class Kaidan;
 class MessageModel;
-class Message;
+struct Message;
 enum class MessageOrigin : quint8;
 
 class RosterModel : public QAbstractListModel
@@ -54,30 +55,86 @@ public:
 		LastExchangedRole,
 		UnreadMessagesRole,
 		LastMessageRole,
+		PinnedRole,
+		DraftIdRole,
 	};
 
+	/**
+	 * Result for adding a contact by an XMPP URI specifying how the URI is used
+	 */
+	enum AddContactByUriResult {
+		AddingContact,  ///< The contact is being added to the roster.
+		ContactExists,  ///< The contact is already in the roster.
+		InvalidUri      ///< The URI cannot be used for contact addition.
+	};
+	Q_ENUM(AddContactByUriResult)
+
 	static RosterModel *instance();
 
 	RosterModel(QObject *parent = nullptr);
 
-	void setMessageModel(MessageModel *model);
-
 	Q_REQUIRED_RESULT bool isEmpty() const;
 	Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 	Q_REQUIRED_RESULT QHash<int, QByteArray> roleNames() const override;
 	Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override;
 
 	/**
-	 * Retrieves the name of a roster item or its JID's local part.
+	 * Returns whether this model has a roster item with the passed properties.
 	 *
-	 * @param accountJid JID of the account whose roster item is retrieved
 	 * @param jid JID of the roster item
 	 *
-	 * @return the name of the roster item, or
-	 * the local part of its JID if the found roster item has no name, or
-	 * an empty string if no roster item with the given JID could be found
+	 * @return true if a roster item with the passed properties exists, otherwise false
 	 */
-	Q_INVOKABLE QString itemName(const QString &accountJid, const QString &jid) const;
+	Q_INVOKABLE bool hasItem(const QString &jid) const;
+
+	/**
+	 * Returns whether an account's presence is subscribed by a roster item.
+	 *
+	 * @param accountJid JID of the account whose roster item's presence subcription is requested
+	 * @param jid JID of the roster item
+	 *
+	 * @return whether the presence is subscribed by the item
+	 */
+	bool isPresenceSubscribedByItem(const QString &accountJid, const QString &jid) const;
+
+	std::optional<Encryption::Enum> itemEncryption(const QString &accountJid, const QString &jid) const;
+	void setItemEncryption(const QString &accountJid, const QString &jid, Encryption::Enum encryption);
+	Q_INVOKABLE void setItemEncryption(const QString &accountJid, Encryption::Enum encryption);
+
+	/**
+	 * Adds a contact (bare JID) by a given XMPP URI (e.g., from a scanned QR
+	 * code) such as "xmpp:user@example.org".
+	 *
+	 * @param uriString XMPP URI string that contains only a JID
+	 */
+	Q_INVOKABLE RosterModel::AddContactByUriResult addContactByUri(const QString &uriString);
+
+	QString lastReadOwnMessageId(const QString &accountJid, const QString &jid) const;
+	QString lastReadContactMessageId(const QString &accountJid, const QString &jid) const;
+	QString draftMessageId(const QString &accountJid, const QString &jid) const;
+
+	/**
+	 * Sends read markers for all roster items that have unsent (pending) ones.
+	 *
+	 * This method must only be called while being logged in.
+	 * Otherwise, the pending states of the read markers would be reset even if the pending read
+	 * markers could not be sent.
+	 *
+	 * @param accountJid bare JID of the user's account
+	 */
+	void sendPendingReadMarkers(const QString &accountJid);
+
+	/**
+	 * Searches for the roster item with a given JID.
+	 */
+	std::optional<RosterItem> findItem(const QString &jid) const;
+
+	Q_INVOKABLE void pinItem(const QString &accountJid, const QString &jid);
+	Q_INVOKABLE void unpinItem(const QString &accountJid, const QString &jid);
+	Q_INVOKABLE void reorderPinnedItem(const QString &accountJid, const QString &jid, int oldIndex, int newIndex);
+
+	Q_INVOKABLE void setChatStateSendingEnabled(const QString &accountJid, const QString &jid, bool chatStateSendingEnabled);
+	Q_INVOKABLE void setReadMarkerSendingEnabled(const QString &accountJid, const QString &jid, bool readMarkerSendingEnabled);
 
 signals:
 	void addItemRequested(const RosterItem &item);
@@ -117,27 +174,16 @@ private slots:
 	void removeItems(const QString &accountJid, const QString &jid = {});
 
 	void handleMessageAdded(const Message &message, MessageOrigin origin);
+	void handleDraftMessageAdded(const Message &message);
+	void handleDraftMessageUpdated(const Message &message);
+	void handleDraftMessageRemoved(const QString &id);
+	void handleDraftMessageFetched(const Message &msg);
 
 private:
-	/**
-	 * Searches for the roster item with a given JID.
-	 */
-	std::optional<const RosterItem> findItem(const QString &jid) const;
-
 	void insertItem(int index, const RosterItem &item);
-	int updateItemPosition(int currentIndex);
-	int positionToInsert(const RosterItem &item);
-
-	/**
-	 * Determines a suitable roster item's name.
-	 *
-	 * @param jid JID of the roster item
-	 * @param name name of the roster item which can be empty
-	 *
-	 * @return the passed item name if it is not empty, otherwise the local
-	 * part of the passed JID
-	 */
-	QString determineItemName(const QString &jid, const QString &name) const;
+	void updateItemPosition(int currentIndex);
+	int positionToAdd(const RosterItem &item);
+	int positionToMove(int currentIndex);
 
 	QVector<RosterItem> m_items;
 
