@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -30,6 +30,8 @@
 
 #include "VCardManager.h"
 
+// Qt
+#include <QBuffer>
 // QXmpp
 #include <QXmppUtils.h>
 #include <QXmppVCardManager.h>
@@ -46,7 +48,9 @@ VCardManager::VCardManager(ClientWorker *clientWorker, QXmppClient *client, Avat
 	connect(m_client, &QXmppClient::presenceReceived, this, &VCardManager::handlePresenceReceived);
 	connect(m_manager, &QXmppVCardManager::clientVCardReceived, this, &VCardManager::handleClientVCardReceived);
 	connect(this, &VCardManager::vCardRequested, this, &VCardManager::requestVCard);
-	connect(this, &VCardManager::changeDisplayNameRequested, this, &VCardManager::changeNickname);
+	connect(this, &VCardManager::clientVCardRequested, this, &VCardManager::requestClientVCard);
+	connect(this, &VCardManager::changeNicknameRequested, this, &VCardManager::changeNickname);
+	connect(this, &VCardManager::changeAvatarRequested, this, &VCardManager::changeAvatar);
 
 	// Currently we're not requesting the own VCard on every connection because it is probably
 	// way too resource intensive on mobile connections with many reconnects.
@@ -60,9 +64,9 @@ VCardManager::VCardManager(ClientWorker *clientWorker, QXmppClient *client, Avat
 void VCardManager::requestVCard(const QString &jid)
 {
 	if (m_client->state() == QXmppClient::ConnectedState)
-		m_client->findExtension<QXmppVCardManager>()->requestVCard(jid);
+		m_manager->requestVCard(jid);
 	else
-		qWarning() << "[VCardManager] Could not fetch VCard: Not connected to a server";
+		qWarning() << "[VCardManager] Could not fetch vCard: Not connected to a server";
 }
 
 void VCardManager::handleVCardReceived(const QXmppVCardIq &iq)
@@ -76,15 +80,27 @@ void VCardManager::handleVCardReceived(const QXmppVCardIq &iq)
 
 void VCardManager::requestClientVCard()
 {
-	m_manager->requestClientVCard();
+	if (m_client->state() == QXmppClient::ConnectedState)
+		m_manager->requestClientVCard();
+	else
+		qWarning() << "[VCardManager] Could not fetch own vCard: Not connected to a server";
 }
 
 void VCardManager::handleClientVCardReceived()
 {
-	if (!m_nicknameToBeSetAfterReceivingCurrentVCard.isEmpty())
+	if (!m_nicknameToBeSetAfterReceivingCurrentVCard.isNull()) {
 		changeNicknameAfterReceivingCurrentVCard();
+	}
 
-	m_clientWorker->caches()->vCardCache->setVCard(m_client->configuration().jidBare(), m_manager->clientVCard());
+	if (!m_avatarToBeSetAfterReceivingCurrentVCard.isNull() || m_isAvatarToBeReset) {
+		changeAvatarAfterReceivingCurrentVCard();
+	}
+
+	const auto &ownJid { m_client->configuration().jidBare() };
+	auto clientVCard { m_manager->clientVCard() };
+	clientVCard.setFrom(ownJid);
+
+	m_clientWorker->caches()->vCardCache->setVCard(ownJid, clientVCard);
 }
 
 void VCardManager::handlePresenceReceived(const QXmppPresence &presence)
@@ -107,13 +123,29 @@ void VCardManager::handlePresenceReceived(const QXmppPresence &presence)
 void VCardManager::changeNickname(const QString &nickname)
 {
 	m_clientWorker->startTask(
-		[=] () {
+		[this, nickname] {
 			m_nicknameToBeSetAfterReceivingCurrentVCard = nickname;
 			requestClientVCard();
 		}
 	);
 }
 
+void VCardManager::changeAvatar(const QImage &avatar)
+{
+	m_clientWorker->startTask(
+		[this, avatar] {
+			// TODO what's the maximum image size that should be saved?
+			if (!avatar.isNull()) {
+				m_avatarToBeSetAfterReceivingCurrentVCard = avatar.scaledToWidth(512);
+			} else {
+				m_isAvatarToBeReset = true;
+			}
+
+			requestClientVCard();
+		}
+	);
+}
+
 void VCardManager::changeNicknameAfterReceivingCurrentVCard()
 {
 	QXmppVCardIq vCardIq = m_manager->clientVCard();
@@ -122,3 +154,27 @@ void VCardManager::changeNicknameAfterReceivingCurrentVCard()
 	m_nicknameToBeSetAfterReceivingCurrentVCard.clear();
 	m_clientWorker->finishTask();
 }
+
+void VCardManager::changeAvatarAfterReceivingCurrentVCard()
+{
+	QXmppVCardIq vCardIq = m_manager->clientVCard();
+
+	if (!m_isAvatarToBeReset) {
+		QByteArray ba;
+		QBuffer buffer(&ba);
+		buffer.open(QIODevice::WriteOnly);
+		m_avatarToBeSetAfterReceivingCurrentVCard.save(&buffer, "JPG");
+
+		vCardIq.setPhoto(ba);
+	} else {
+		m_isAvatarToBeReset = false;
+		vCardIq.setPhoto({});
+	}
+
+	m_manager->setClientVCard(vCardIq);
+
+	m_avatarToBeSetAfterReceivingCurrentVCard = {};
+	m_clientWorker->finishTask();
+
+	emit Kaidan::instance()->avatarChangeSucceeded();
+}
