@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2021 Kaidan developers and contributors
+ *  Copyright (C) 2016-2023 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -48,6 +48,8 @@
 #include <QXmppResultSet.h>
 #include <QXmppVersionIq.h>
 
+#include "qxmpp-exts/QXmppUri.h"
+
 // Kaidan
 #include "AccountManager.h"
 #include "AudioDeviceModel.h"
@@ -59,46 +61,56 @@
 #include "DataFormModel.h"
 #include "DiscoveryManager.h"
 #include "EmojiModel.h"
+#include "Encryption.h"
 #include "Enums.h"
+#include "FileProgressCache.h"
+#include "FileSharingController.h"
 #include "GuiStyle.h"
 #include "Kaidan.h"
 #include "MediaUtils.h"
 #include "MediaRecorder.h"
 #include "Message.h"
+#include "MessageComposition.h"
 #include "MessageModel.h"
 #include "MessageHandler.h"
+#include "OmemoManager.h"
+#include "OmemoWatcher.h"
+#include "PublicGroupChatModel.h"
+#include "PublicGroupChatProxyModel.h"
+#include "PublicGroupChatSearchManager.h"
 #include "QmlUtils.h"
 #include "QrCodeGenerator.h"
 #include "QrCodeScannerFilter.h"
 #include "RegistrationDataFormFilterModel.h"
 #include "RegistrationManager.h"
+#include "RosterItemWatcher.h"
 #include "RosterManager.h"
 #include "RosterModel.h"
 #include "RosterFilterProxyModel.h"
 #include "ServerFeaturesCache.h"
-#include "ServerListModel.h"
+#include "ProviderListModel.h"
 #include "StatusBar.h"
-#include "TransferCache.h"
-#include "UploadManager.h"
 #include "UserDevicesModel.h"
 #include "VCardModel.h"
 #include "VCardManager.h"
 #include "VersionManager.h"
+#include "RecentPicturesModel.h"
+#include "NotificationsMutedWatcher.h"
 
 Q_DECLARE_METATYPE(Qt::ApplicationState)
 
 Q_DECLARE_METATYPE(QXmppClient::State)
-#if QXMPP_VERSION < QT_VERSION_CHECK(1, 4, 0)
-Q_DECLARE_METATYPE(QXmppMessage)
-#endif
 Q_DECLARE_METATYPE(QXmppMessage::State)
 Q_DECLARE_METATYPE(QXmppDiscoveryIq);
 Q_DECLARE_METATYPE(QXmppPresence)
 Q_DECLARE_METATYPE(QXmppStanza::Error)
 Q_DECLARE_METATYPE(QXmppResultSetReply);
+Q_DECLARE_METATYPE(QXmpp::TrustLevel);
+Q_DECLARE_METATYPE(QXmppUri)
 Q_DECLARE_METATYPE(QXmppVCardIq)
 Q_DECLARE_METATYPE(QXmppVersionIq)
 
+Q_DECLARE_METATYPE(std::function<void()>)
 Q_DECLARE_METATYPE(std::function<void(RosterItem&)>)
 Q_DECLARE_METATYPE(std::function<void(Message&)>)
 
@@ -146,7 +158,9 @@ CommandLineParseResult parseCommandLine(QCommandLineParser &parser, QString *err
 	QCommandLineOption helpOption = parser.addHelpOption();
 	QCommandLineOption versionOption = parser.addVersionOption();
 	parser.addOption({"disable-xml-log", "Disable output of full XMPP XML stream."});
+#ifndef NDEBUG
 	parser.addOption({{"m", "multiple"}, "Allow multiple instances to be started."});
+#endif
 	parser.addPositionalArgument("xmpp-uri", "An XMPP-URI to open (i.e. join a chat).",
 	                             "[xmpp-uri]");
 
@@ -192,6 +206,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	QGuiApplication::setApplicationName(APPLICATION_NAME);
 	QGuiApplication::setApplicationDisplayName(APPLICATION_DISPLAY_NAME);
 	QGuiApplication::setApplicationVersion(VERSION_STRING);
+	QGuiApplication::setDesktopFileName(APPLICATION_ID);
 	// attributes
 	QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 	QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
@@ -234,24 +249,26 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 #endif // APPIMAGE
 
 	// register qMetaTypes
+	qRegisterMetaType<ProviderListItem>();
 	qRegisterMetaType<RosterItem>();
+	qRegisterMetaType<RosterItemWatcher *>();
 	qRegisterMetaType<RosterModel*>();
 	qRegisterMetaType<RosterManager*>();
 	qRegisterMetaType<Message>();
 	qRegisterMetaType<MessageModel*>();
 	qRegisterMetaType<MessageHandler*>();
 	qRegisterMetaType<DiscoveryManager*>();
-	qRegisterMetaType<UploadManager*>();
 	qRegisterMetaType<VCardManager*>();
 	qRegisterMetaType<VersionManager*>();
 	qRegisterMetaType<RegistrationManager*>();
+	qRegisterMetaType<FileSharingController *>();
+	qRegisterMetaType<OmemoManager *>();
 	qRegisterMetaType<AvatarFileStorage*>();
-	qRegisterMetaType<QXmppPresence>();
-	qRegisterMetaType<TransferJob*>();
 	qRegisterMetaType<QmlUtils*>();
 	qRegisterMetaType<QVector<Message>>();
 	qRegisterMetaType<QVector<RosterItem>>();
 	qRegisterMetaType<QHash<QString,RosterItem>>();
+	qRegisterMetaType<std::function<void()>>();
 	qRegisterMetaType<std::function<void(RosterItem&)>>();
 	qRegisterMetaType<std::function<void(Message&)>>();
 	qRegisterMetaType<QXmppVCardIq>();
@@ -264,6 +281,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qRegisterMetaType<VideoEncoderSettings>();
 	qRegisterMetaType<CredentialsValidator*>();
 	qRegisterMetaType<QXmppVersionIq>();
+	qRegisterMetaType<QXmppUri>();
+	qRegisterMetaType<QMap<QString, QUrl>>();
 
 	// Enums for c++ member calls using enums
 	qRegisterMetaType<Qt::ApplicationState>();
@@ -272,6 +291,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qRegisterMetaType<QXmppStanza::Error>();
 	qRegisterMetaType<MessageType>();
 	qRegisterMetaType<Enums::ConnectionState>();
+	qRegisterMetaType<PublicGroupChatModel::CustomRole>();
 	qRegisterMetaType<ClientWorker::ConnectionError>();
 	qRegisterMetaType<Enums::MessageType>();
 	qRegisterMetaType<Presence::Availability>();
@@ -285,13 +305,16 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qRegisterMetaType<MediaRecorder::State>();
 	qRegisterMetaType<MediaRecorder::Status>();
 	qRegisterMetaType<MediaRecorder::Error>();
-	qRegisterMetaType<ServerListModel::Role>();
+	qRegisterMetaType<ProviderListModel::Role>();
 	qRegisterMetaType<ChatState::State>();
+	qRegisterMetaType<Encryption>();
 
 	// QXmpp
 	qRegisterMetaType<QXmppResultSetReply>();
 	qRegisterMetaType<QXmppMessage>();
+	qRegisterMetaType<QXmppPresence>();
 	qRegisterMetaType<QXmppDiscoveryIq>();
+	qRegisterMetaType<QHash<QString, QHash<QByteArray, QXmpp::TrustLevel>>>();
 
 	// Qt-Translator
 	QTranslator qtTranslator;
@@ -299,12 +322,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	                  QLibraryInfo::location(QLibraryInfo::TranslationsPath));
 	QCoreApplication::installTranslator(&qtTranslator);
 
-	// Kaidan-Translator
-	QTranslator kaidanTranslator;
-	// load the systems locale or none from resources
-	kaidanTranslator.load(QLocale::system().name(), ":/i18n");
-	QCoreApplication::installTranslator(&kaidanTranslator);
-
 	//
 	// Command line arguments
 	//
@@ -328,11 +345,16 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	}
 
 #if !defined(Q_OS_IOS) && !defined(Q_OS_ANDROID)
+#ifdef NDEBUG
+	if (app.isSecondary()) {
+		qDebug() << "Another instance of" << APPLICATION_DISPLAY_NAME << "is already running!";
+#else
 	// check if another instance already runs
 	if (app.isSecondary() && !parser.isSet("multiple")) {
 		qDebug().noquote() << QString("Another instance of %1 is already running.")
 		                      .arg(APPLICATION_DISPLAY_NAME)
 		                   << "You can enable multiple instances by specifying '--multiple'.";
+#endif
 
 		// send a possible link to the primary instance
 		if (const auto positionalArguments = parser.positionalArguments(); !positionalArguments.isEmpty())
@@ -393,6 +415,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qmlRegisterType<QrCodeScannerFilter>(APPLICATION_ID, 1, 0, "QrCodeScannerFilter");
 	qmlRegisterType<VCardModel>(APPLICATION_ID, 1, 0, "VCardModel");
 	qmlRegisterType<RosterFilterProxyModel>(APPLICATION_ID, 1, 0, "RosterFilterProxyModel");
+	qmlRegisterType<MessageComposition>(APPLICATION_ID, 1, 0, "MessageComposition");
+	qmlRegisterType<FileSelectionModel>(APPLICATION_ID, 1, 0, "FileSelectionModel");
 	qmlRegisterType<CameraModel>(APPLICATION_ID, 1, 0, "CameraModel");
 	qmlRegisterType<AudioDeviceModel>(APPLICATION_ID, 1, 0, "AudioDeviceModel");
 	qmlRegisterType<MediaSettingsContainerModel>(APPLICATION_ID, 1, 0, "MediaSettingsContainerModel");
@@ -409,12 +433,20 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qmlRegisterType<CredentialsValidator>(APPLICATION_ID, 1, 0, "CredentialsValidator");
 	qmlRegisterType<QrCodeGenerator>(APPLICATION_ID, 1, 0, "QrCodeGenerator");
 	qmlRegisterType<RegistrationDataFormFilterModel>(APPLICATION_ID, 1, 0, "RegistrationDataFormFilterModel");
-	qmlRegisterType<ServerListModel>(APPLICATION_ID, 1, 0, "ServerListModel");
+	qmlRegisterType<ProviderListModel>(APPLICATION_ID, 1, 0, "ProviderListModel");
+	qmlRegisterType<FileProgressWatcher>(APPLICATION_ID, 1, 0, "FileProgressWatcher");
 	qmlRegisterType<UserPresenceWatcher>(APPLICATION_ID, 1, 0, "UserPresenceWatcher");
+	qmlRegisterType<UserResourcesWatcher>(APPLICATION_ID, 1, 0, "UserResourcesWatcher");
+	qmlRegisterType<RosterItemWatcher>(APPLICATION_ID, 1, 0, "RosterItemWatcher");
+	qmlRegisterType<RecentPicturesModel>(APPLICATION_ID, 1, 0, "RecentPicturesModel");
+	qmlRegisterType<NotificationsMutedWatcher>(APPLICATION_ID, 1, 0, "NotificationsMutedWatcher");
+	qmlRegisterType<PublicGroupChatSearchManager>("PublicGroupChats", 1, 0, "SearchManager");
+	qmlRegisterType<PublicGroupChatModel>("PublicGroupChats", 1, 0, "Model");
+	qmlRegisterType<PublicGroupChatProxyModel>("PublicGroupChats", 1, 0, "ProxyModel");
+	qmlRegisterType<OmemoWatcher>(APPLICATION_ID, 1, 0, "OmemoWatcher");
 
 	qmlRegisterUncreatableType<QAbstractItemModel>("EmojiModel", 0, 1, "QAbstractItemModel", "Used by proxy models");
 	qmlRegisterUncreatableType<Emoji>("EmojiModel", 0, 1, "Emoji", "Used by emoji models");
-	qmlRegisterUncreatableType<TransferJob>(APPLICATION_ID, 1, 0, "TransferJob", "TransferJob type usable");
 	qmlRegisterUncreatableType<QMimeType>(APPLICATION_ID, 1, 0, "QMimeType", "QMimeType type usable");
 	qmlRegisterUncreatableType<CameraInfo>(APPLICATION_ID, 1, 0, "CameraInfo", "CameraInfo type usable");
 	qmlRegisterUncreatableType<AudioDeviceInfo>(APPLICATION_ID, 1, 0, "AudioDeviceInfo", "AudioDeviceInfo type usable");
@@ -429,8 +461,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qmlRegisterUncreatableType<RegistrationManager>(APPLICATION_ID, 1, 0, "RegistrationManager", "Cannot create object; only enums defined!");
 	qmlRegisterUncreatableType<ChatState>(APPLICATION_ID, 1, 0, "ChatState", "Cannot create object; only enums defined");
 	qmlRegisterUncreatableType<RosterModel>(APPLICATION_ID, 1, 0, "RosterModel", "Cannot create object; only enums defined!");
-	qmlRegisterUncreatableType<TransferCache>(APPLICATION_ID, 1, 0, "TransferCache", "TransferCache type usable");
 	qmlRegisterUncreatableType<ServerFeaturesCache>(APPLICATION_ID, 1, 0, "ServerFeaturesCache", "ServerFeaturesCache type usable");
+	qmlRegisterUncreatableType<Encryption>(APPLICATION_ID, 1, 0, "Encryption", "Cannot create object; only enums defined!");
+	qmlRegisterUncreatableType<File>(APPLICATION_ID, 1, 0, "File", "Not creatable from QML");
+	qmlRegisterUncreatableType<PublicGroupChat>("PublicGroupChats", 1, 0, "PublicGroupChat", "Used by PublicGroupChatModel");
 
 	qmlRegisterUncreatableMetaObject(ChatState::staticMetaObject, APPLICATION_ID, 1, 0, "ChatState", "Can't create object; only enums defined!");
 	qmlRegisterUncreatableMetaObject(Enums::staticMetaObject, APPLICATION_ID, 1, 0, "Enums", "Can't create object; only enums defined!");
