@@ -25,9 +25,21 @@ echo "*****************************************"
 
 export PKG_CONFIG_EXECUTABLE=/usr/local/bin/pkg-config
 
-if [ ! -f "$KAIDAN_SOURCES/3rdparty/kirigami/.git" ] || [ ! -f "$KAIDAN_SOURCES/3rdparty/breeze-icons/.git" ]; then
-    echo "Cloning Kirigami, Breeze icons, QXmpp and ZXing-cpp"
-    git submodule update --init
+mkdir -p $KAIDAN_SOURCES/3rdparty
+
+if [ ! -f "$KAIDAN_SOURCES/3rdparty/kirigami/.git" ]; then
+    echo "Cloning Kirigami"
+    git clone https://invent.kde.org/frameworks/kirigami $KAIDAN_SOURCES/3rdparty/kirigami
+fi
+
+if [ ! -e "$KAIDAN_SOURCES/3rdparty/breeze-icons/.git" ]; then
+    echo "Cloning Breeze icons"
+    git clone https://invent.kde.org/frameworks/breeze-icons $KAIDAN_SOURCES/3rdparty/breeze-icons
+fi
+
+if [ ! -e "$KAIDAN_SOURCES/3rdparty/qxmpp/.git" ]; then
+    echo "Cloning QXmpp"
+    git clone https://github.com/qxmpp-project/qxmpp.git $KAIDAN_SOURCES/3rdparty/qxmpp
 fi
 
 if [ ! -d "$KAIDAN_SOURCES/3rdparty/ios-cmake/.git" ]; then
