@@ -63,6 +63,7 @@ REPLACE_USER_IDS = [
 	("papadop _ <papadop@protonmail.com>", "papadop <papadop@protonmail.com>"),
 	("Anna _ <bs@sysrq.in>", "Anna <bs@sysrq.in>"),
 	("marek _ <Marek@walczak.io>", "marek <marek@walczak.io>"),
+    ("TigranKhachatryan0 _ <tigrank2008@gmail.com>", "TigranKhachatryan0 <tigrank2008@gmail.com>"),
 ]
 
 # These user ids will be excluded from any targets
@@ -304,10 +305,6 @@ def main():
 				"Eike Hein <hein@kde.org>": CopyrightAuthor(years = "2017-2018")
 			}
 		),
-		CopyrightTarget(
-			directories = ["i18n"],
-			licenseName = "GPL-3+ with OpenSSL exception"
-		),
 		CopyrightTarget(
 			files = ["src/StatusBar.cpp", "src/StatusBar.h", "src/singleapp/*",
 				 "src/hsluv-c/*", "utils/generate-license.py"],
@@ -366,29 +363,18 @@ def main():
 			authorList = {
 				"Ilya Bizyaev <bizyaev@zoho.com>": CopyrightAuthor(years = "2016-2017"),
 				"Mathis Brüchert <mbblp@protonmail.ch>": CopyrightAuthor(years = "2020"),
-				"Melvin Keskin <melvo@olomono.de": CopyrightAuthor(years = "2020"),
+				"Melvin Keskin <melvo@olomono.de>": CopyrightAuthor(years = "2020"),
 			}
 		),
 		CopyrightTarget(
 			files = ["data/images/chat-page-background.svg"],
 			licenseName = "CC-BY-SA-4.0",
 			authorList = {
-				"Mathis Brüchert <mbblp@protonmail.ch>": CopyrightAuthor(years = "2019"),
-				"Melvin Keskin <melvo@olomono.de>": CopyrightAuthor(years = "2019")
+				"Raghavendra Kamath <raghu@raghukamath.com>": CopyrightAuthor(years = "2022"),
 			},
-			comment = "Inspired by graphic from https://www.toptal.com/designers/subtlepatterns/"
-		),
-		CopyrightTarget(
-			files = ["data/images/global-drawer-banner.svg"],
-			licenseName = "CC-BY-SA-4.0",
-			authorList = {
-				"Mathis Brüchert <mbblp@protonmail.ch>": CopyrightAuthor(years = "2020")
-			}
 		),
 		CopyrightTarget(
 			files = [
-				"data/images/account-deletion-from-client.svg",
-				"data/images/account-deletion-from-client-and-server.svg",
 				"data/images/onboarding/account-transfer.svg",
 				"data/images/onboarding/automatic-registration.svg",
 				"data/images/onboarding/custom-form.svg",
@@ -415,6 +401,27 @@ def main():
 				"Mathis Brüchert <mbblp@protonmail.ch>": CopyrightAuthor(years = "2020")
 			}
 		),
+		CopyrightTarget(
+			files = [
+				"data/images/qr-code-scan-1.svg",
+				"data/images/qr-code-scan-2.svg",
+			],
+			licenseName = "CC-BY-SA-4.0",
+			authorList = {
+				"Mathis Brüchert <mbblp@protonmail.ch>": CopyrightAuthor(years = "2021")
+			}
+		),
+		CopyrightTarget(
+			files = [
+				"data/images/qr-code-scan-own-1.svg",
+				"data/images/qr-code-scan-own-2.svg",
+			],
+			licenseName = "CC-BY-SA-4.0",
+			authorList = {
+				"Mathis Brüchert <mbblp@protonmail.ch>": CopyrightAuthor(years = "2021"),
+				"Melvin Keskin <melvo@olomono.de>": CopyrightAuthor(years = "2022")
+			}
+		),
 		CopyrightTarget(
 			files = ["utils/convert-prl-libs-to-cmake.pl"],
 			licenseName = "MIT-Apple",
