@@ -1,6 +1,7 @@
 #!/bin/bash
 
 KAIDAN_SOURCES=$(dirname "$(readlink -f "${0}")")/..
+OPTIMIZE_PNG_SCRIPT="${KAIDAN_SOURCES}/utils/optimize-png.sh"
 
 echo "*****************************************"
 echo "Rendering logos"
@@ -8,8 +9,7 @@ echo "*****************************************"
 
 rendersvg() {
     inkscape -o $2 -w $3 -h $3 $1 >/dev/null
-    optipng -quiet -o7 $2 >/dev/null
-    advpng -z4 $2 >/dev/null
+    "${OPTIMIZE_PNG_SCRIPT}" "${2}"
 }
 
 androidlogo() {
